Please see [https://docs.mlcommons.org/cm4mlops/scripts/Modular-MLPerf-training-benchmark-pipeline/app-mlperf-training-nvidia](https://docs.mlcommons.org/cm4mlops/scripts/Modular-MLPerf-training-benchmark-pipeline/app-mlperf-training-nvidia) for the documentation of this CM script.
